==> monodevelop_2.0%2Bdfsg.orig.tar.gz: monodevelop-2.0/src/core/MonoDevelop.Ide/MonoDevelop.Ide.Gui.OptionPanels/GlobalAuthorInformationPanel.cs <==
// 
// GlobalAuthorInformationPanelWidget.cs
// 
// Author:
//   Michael Hutchinson <mhutchinson@novell.com>
// 
// Copyright (C) 2009 Novell, Inc (http://www.novell.com)
// 
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

using System;
using MonoDevelop.Core;
using MonoDevelop.Core.Gui.Dialogs;

namespace MonoDevelop.Ide.Gui.OptionPanels
{
	class GlobalAuthorInformationPanel : OptionsPanel
	{
		GlobalAuthorInformationPanelWidget widget;
		
		public override Gtk.Widget CreatePanelWidget ()
		{
			return widget = new GlobalAuthorInformationPanelWidget ();
		}

		public override void ApplyChanges ()
		{
			widget.Save ();
		}
	}
	
	partial class GlobalAuthorInformationPanelWidget : Gtk.Bin
	{
		
		public GlobalAuthorInformationPanelWidget()
		{
			this.Build ();
			
			nameEntry.Text = AuthorInformation.Default.Name ?? "";
			emailEntry.Text = AuthorInformation.Default.Email ?? "";
			copyrightEntry.Text = AuthorInformation.Default.Copyright ?? "";
		}
		
		public void Save ()
		{
			PropertyService.Set ("Author.Name", nameEntry.Text);
			PropertyService.Set ("Author.Email", emailEntry.Text);
			PropertyService.Set ("Author.Copyright", copyrightEntry.Text);
		}
	}
}

==> monodevelop_3.0.2%2Bdfsg.orig.tar.gz: monodevelop-3.0.2/src/core/MonoDevelop.Ide/MonoDevelop.Ide.Gui.OptionPanels/GlobalAuthorInformationPanel.cs <==
// 
// GlobalAuthorInformationPanelWidget.cs
// 
// Author:
//   Michael Hutchinson <mhutchinson@novell.com>
// 
// Copyright (C) 2009 Novell, Inc (http://www.novell.com)
// 
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

using System;
using MonoDevelop.Core;
using MonoDevelop.Ide.Gui.Dialogs;
using MonoDevelop.Projects;

namespace MonoDevelop.Ide.Gui.OptionPanels
{
	class GlobalAuthorInformationPanel : OptionsPanel
	{
		GlobalAuthorInformationPanelWidget widget;
		
		public override Gtk.Widget CreatePanelWidget ()
		{
			return widget = new GlobalAuthorInformationPanelWidget ();
		}

		public override void ApplyChanges ()
		{
			widget.Save ();
		}
	}
	
	partial class GlobalAuthorInformationPanelWidget : Gtk.Bin
	{
		
		public GlobalAuthorInformationPanelWidget()
		{
			this.Build ();
			
			nameEntry.Text = AuthorInformation.Default.Name ?? "";
			emailEntry.Text = AuthorInformation.Default.Email ?? "";
			copyrightEntry.Text = AuthorInformation.Default.Copyright ?? "";
			companyEntry.Text = AuthorInformation.Default.Company ?? "";
			trademarkEntry.Text = AuthorInformation.Default.Trademark ?? "";
		}
		
		public void Save ()
		{
			PropertyService.Set ("Author.Name", nameEntry.Text);
			PropertyService.Set ("Author.Email", emailEntry.Text);
			PropertyService.Set ("Author.Copyright", copyrightEntry.Text);
			PropertyService.Set ("Author.Company", companyEntry.Text);
			PropertyService.Set ("Author.Trademark", trademarkEntry.Text);
		}
	}
}
